@@ -284,10 +284,9 @@ impl<T: Send + Sync + 'static> DelayTaskHandler for SmolTask<T> {
 }
 
 use tokio::task::JoinHandle;
-//TODO:remove debug.
 impl<T: Send + Sync + Debug + 'static> DelayTaskHandler for JoinHandle<T> {
     fn quit(self: Box<Self>) -> Result<()> {
-        (&*self).abort();
+        (*self).abort();
         Ok(())
     }
 }
