@@ -17,6 +17,7 @@ fn test_instance_state() -> anyhow::Result<()> {
     let delay_timer = DelayTimer::new();
 
     let body = || async {
+        println!("create_async_fn_body:i'success");
         Timer::after(Duration::from_millis(100)).await;
     };
 
@@ -25,6 +26,7 @@ fn test_instance_state() -> anyhow::Result<()> {
         .set_task_id(1)
         .set_maximum_parallel_runnable_num(3)
         .spawn_async_routine(body)?;
+
     let task_instance_chain = delay_timer.insert_task(task)?;
 
     // Get the first task instance.
@@ -35,6 +37,7 @@ fn test_instance_state() -> anyhow::Result<()> {
 
     // Unsolicited mission cancellation.
     instance.cancel_with_wait()?;
+
     assert_eq!(instance.get_state(), instance::CANCELLED);
 
     // Get the second task instance.
@@ -52,8 +55,8 @@ fn test_instance_state() -> anyhow::Result<()> {
     Ok(())
 }
 
-#[test]
-fn test_instance_timeout_state() -> anyhow::Result<()> {
+#[tokio::test]
+async fn test_instance_timeout_state() -> anyhow::Result<()> {
     let delay_timer = DelayTimer::new();
 
     let body = || async {
@@ -171,8 +174,8 @@ fn test_shell_task_instance_complete_state() -> anyhow::Result<()> {
     Ok(())
 }
 
-#[test]
-fn go_works() -> AnyResult<()> {
+#[tokio::test]
+async fn go_works() -> AnyResult<()> {
     // Coordinates the inner-Runtime with the external(test-thread) clock.
     let expression = "0/2 * * * * * *";
     let park_time = 2_100_000u64;
@@ -235,8 +238,8 @@ fn test_advance() -> AnyResult<()> {
     Ok(())
 }
 
-#[test]
-fn test_maximum_parallel_runnable_num() -> AnyResult<()> {
+#[tokio::test]
+async fn test_maximum_parallel_runnable_num() -> AnyResult<()> {
     let delay_timer = DelayTimer::new();
     let share_num = Arc::new(AtomicU64::new(0));
     let share_num_bunshin = share_num.clone();
@@ -326,9 +329,13 @@ fn inspect_struct() -> AnyResult<()> {
 
 #[test]
 fn test_cron_clock() -> AnyResult<()> {
-    let mut s = cron_clock::Schedule::from_str("0 15 06 * * * *")?.upcoming_owned(cron_clock::Utc);
+    let mut s =
+        cron_clock::Schedule::from_str("0 10 22 * * Monday,Tuesday,Wednesday,Thursday,Friday *")?
+            .upcoming_owned(cron_clock::Utc);
+
+    for _ in 0..10 {
+        println!("{:?}", s.next());
+    }
 
-    println!("{:?}", s.next());
-    println!("{:?}", s.next());
     Ok(())
 }
